@@ -189,6 +189,11 @@ def gnssir(station: str, year: int, doy: int, snr: int = 66, plt: bool = False,
     if delTmax is not None:
         lsp['delTmax'] = delTmax
 
+    if ((lsp['maxH'] - lsp['minH']) < 5):
+        print('Requested reflector heights (', lsp['minH'], ',', lsp['maxH'], ') are too close together. Exiting.')
+        print('They must be at least 5 meters apart - and preferably further than that.')
+        sys.exit()
+
     # compress is False unless user changes
     lsp['wantCompression'] = compress
 
@@ -279,6 +284,8 @@ def gnssir(station: str, year: int, doy: int, snr: int = 66, plt: bool = False,
     year_list = list(range(year_st, year_end+1))
     # changed to better describe year and doy start/end
 
+    print('requested frequencies ', lsp['freqs'])
+
     for year in year_list:
         # edits made 2021Sep10 by Makan karegar
         if year != year_end:
