@@ -200,6 +200,10 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
         elif (archive == 'unavco'):
             dir1 = 'https://data.unavco.org/archive/gnss/rinex3/obs/' + cyyyy + '/' + cdoy + '/'
             wget.download(dir1+file_name,file_name)
+        elif (archive == 'gfz'):
+            # no idea
+            dir1 = 'ftp://isdcftp.gfz-potsdam.de/gnss/data/daily/' + cyyyy + '/' + cdoy
+            wget.download(dir1+file_name,file_name)
         elif (archive == 'cddis'):
             new_way_dir = '/gnss/data/daily/' + cyyyy + '/' + cdoy + '/' + cyy + 'd/'
             g.cddis_download_2022B(file_name,new_way_dir)
