@@ -140,7 +140,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     pele : list of floats
         is the elevation angle limits for the polynomial removal.  units: degrees
     satsel : int
-        satellite number?
+        satellite number
     PkNoise : float
         peak to noise ratio for QC
     fortran : bool
@@ -259,9 +259,19 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
         if pltscreen:
             plt.figure(figsize=(10,6))
         allpoints = 0
+
+
         for a in range(naz):
             if pltscreen:
-                plt.subplot(2,2,bz[a])
+                if a==0:
+                    ax1=plt.subplot(2,2,bz[a])
+                if a==1:
+                    ax2=plt.subplot(2,2,bz[a])
+                if a==2:
+                    ax3=plt.subplot(2,2,bz[a])
+                if a==3:
+                    ax4=plt.subplot(2,2,bz[a])
+
                 plt.title(titles[a],fontsize=fs)
             az1 = azval[(a*2)] ; az2 = azval[(a*2 + 1)]
 
@@ -307,7 +317,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                         data[idc][satNu] = [px,pz]
                         datakey[idc][satNu] = [avgAzim, maxF, satNu,f,maxAmp,maxAmp/Noise, UTCtime]
                         if screenstats:
-                            print('SUCCESS for Azimu {0:5.1f} Satellite {1:2.0f} UTC {2:5.2f} RH {3:7.3f} '.format( avgAzim,satNu,UTCtime,maxF))
+                            print('SUCCESS for Azimu {0:5.1f} Satellite {1:2.0f} UTC {2:5.2f} RH {3:7.3f} PkNoise {4:6.2f}'.format( avgAzim,satNu,UTCtime,maxF,maxAmp/Noise))
 
                     else:
                         # these are failed tracks
@@ -340,10 +350,16 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                 plt.yticks(fontsize=fs)
 
         rhout.close()
+        if pltscreen:
+            d1=ax1.get_ylim() ; d2=ax2.get_ylim() ; d3=ax3.get_ylim() ; d4=ax4.get_ylim()
+            minv = min([d1[0], d2[0], d3[0], d4[0]])
+            maxv = max([d1[1], d2[1], d3[1], d4[1]])
+            ax1.set_ylim(minv,maxv) ; ax2.set_ylim(minv,maxv) ;
+            ax3.set_ylim(minv,maxv) ; ax4.set_ylim(minv,maxv)
+
         #print('preliminary reflector height results are stored in a file called logs/rh.txt')
         # this file seems to have an empty line at the end.  i do not know why.
 
-
         # make sure directory exists for plots
         g.set_subdir(station)
         # where plots will go
@@ -358,6 +374,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
             goodbad(quicklog,station,year,doy,minH,maxH,PkNoise,reqAmp,f,e1,e2)
         else:
             print('You made a selection that does not exist (i.e. frequency or satellite or constellation)')
+
         if pltscreen:
             plt.show()
     else: 
@@ -470,3 +487,5 @@ def goodbad(fname,station,year,doy,h1,h2,PkNoise,reqAmp,freq,e1,e2):
     print('plot saved to ', f)
     plt.savefig(f)
 
+
+
