@@ -383,16 +383,18 @@ def write_coords(lng, lat):
 
     return points
 
-
-def make_FZ_kml(name,freq, el_list, h, lat,lng,azlist):
+# Function makes the fresnel zones to KML file
+def make_FZ_kml(station, filename,freq, el_list, h, lat,lng,azlist):
     """
     makes fresnel zones for given azimuth and elevation angle 
     lists.  
 
     Parameters
     ----------
-    name : str
-        output filename (kml will be added to it)
+    station: str
+        four character station name
+    filename : str
+        output filename (the kml extension should already be there)
     freq : int
         frequency (1,2, or 5)
     el_list : list of floatss
@@ -418,8 +420,7 @@ def make_FZ_kml(name,freq, el_list, h, lat,lng,azlist):
         lng_el, lat_el = makeEllipse_latlon(freq,el,h,azim, lat,lng)
         points = write_coords(lng_el, lat_el)
         pname = 'ElevAngle {0}'.format(int(el))
-        ls = kml.newpolygon(name=pname, altitudemode='relativeToGround')
-        #ls = kml.newpolygon(name=pname)
+        ls = kml.newpolygon(name=pname, altitudemode='relativeToGround') # creating new polygon for each azimuth zone in azlist
         ls.outerboundaryis = points
         # print(points)
         if el ==el_list[0]:
@@ -466,8 +467,14 @@ def make_FZ_kml(name,freq, el_list, h, lat,lng,azlist):
         ls.style.linestyle.color = simplekml.Color.yellow
         ls.style.linestyle.width = 3
         ls.style.polystyle.color = simplekml.Color.changealphaint(50, simplekml.Color.yellow)
+
+    # try adding a point at the station
+    pnt = kml.newpoint(name=station)
+    pnt.coords = [(lng, lat)]
+    pnt.style.iconstyle.icon.href = 'http://maps.google.com/mapfiles/kml/shapes/placemark_circle.png'
+
     # save to a file
-    kml.save(name +'.kml')
+    kml.save(filename)
     return True
 
 def set_system(system):
